@@ -14,6 +14,7 @@
 * limitations under the License.
 */
 
+#include <ctype.h>
 #include <errno.h>
 #include <fts.h>
 #include <stdio.h>
@@ -39,13 +40,12 @@ enum selint_error load_access_vectors_kernel(const char *av_path)
 	}
 
 	enum selint_error r = SELINT_PARSE_ERROR;
-	const char *paths[2] = { av_path, NULL };
+	char *av_path_copy = xstrdup(av_path);
+	char *const paths[2] = { av_path_copy, NULL };
 
-IGNORE_CONST_DISCARD_BEGIN;
 	FTS *ftsp = fts_open(paths, FTS_PHYSICAL, NULL);
-IGNORE_CONST_DISCARD_END;
 
-	FTSENT *file = fts_read(ftsp);
+	const FTSENT *file = fts_read(ftsp);
 
 	while (file) {
 
@@ -66,6 +66,7 @@ IGNORE_CONST_DISCARD_END;
 		file = fts_read(ftsp);
 	}
 	fts_close(ftsp);
+	free(av_path_copy);
 
 	return r;
 }
@@ -76,7 +77,7 @@ enum selint_error load_access_vectors_source(const char *av_path)
 
 	set_current_module_name(av_path);
 
-	FILE *f = fopen(av_path, "r");
+	FILE *f = fopen(av_path, "re");
 	if (!f) {
 		printf("%sError%s: Failed to open %s: %s\n", color_error(), color_reset(), av_path, strerror(errno));
 		return SELINT_IO_ERROR;
@@ -93,6 +94,75 @@ enum selint_error load_access_vectors_source(const char *av_path)
 	return SELINT_SUCCESS;
 }
 
+enum selint_error load_security_classes_source(const char *sec_class_path)
+{
+	FILE *fd = fopen(sec_class_path, "r");
+
+	if (!fd) {
+		return SELINT_IO_ERROR;
+	}
+
+	enum selint_error ret = SELINT_SUCCESS;
+
+	char *line = NULL;
+	ssize_t len_read = 0;
+	size_t buf_len = 0;
+	while ((len_read = getline(&line, &buf_len, fd)) != -1) {
+		if (len_read <= 1 || line[0] == '#') {
+			continue;
+		}
+
+		const char *pos = line;
+		if (0 != strncmp(pos, "class", strlen("class"))) {
+			ret = SELINT_PARSE_ERROR;
+			break;
+		}
+		pos += strlen("class");
+
+		if (*pos != ' ' && *pos != '\t') {
+			ret = SELINT_PARSE_ERROR;
+			break;
+		}
+
+		while (*pos == ' ' || *pos == '\t') {
+			pos++;
+		}
+
+		if (!isalnum((unsigned char)*pos)) {
+			ret = SELINT_PARSE_ERROR;
+			break;
+		}
+
+		const char *name_start = pos;
+
+		while (*pos == '_' || isalnum((unsigned char)*pos)) {
+			pos++;
+		}
+
+		const char *name_end = pos;
+
+		while (isspace((unsigned char)*pos)) {
+			pos++;
+		}
+
+		if (*pos != '\0' && *pos != '#') {
+			ret = SELINT_PARSE_ERROR;
+			break;
+		}
+
+		if (*pos == '#' && NULL != strstr(pos, "userspace")) {
+			char *name = strndup(name_start, (size_t)(name_end - name_start));
+			mark_userspace_class(name);
+			free(name);
+		}
+	}
+
+	free(line);
+	fclose(fd);
+
+	return ret;
+}
+
 void load_modules_normal(void)
 {
 
@@ -123,7 +193,7 @@ static char *strip_space(char *str)
 
 enum selint_error load_modules_source(const char *modules_conf_path)
 {
-	FILE *fd = fopen(modules_conf_path, "r");
+	FILE *fd = fopen(modules_conf_path, "re");
 
 	if (!fd) {
 		return SELINT_IO_ERROR;
@@ -149,14 +219,14 @@ enum selint_error load_modules_source(const char *modules_conf_path)
 			fclose(fd);
 			return SELINT_PARSE_ERROR;
 		}
-		char *mod_name = strip_space(pos);
+		const char *mod_name = strip_space(pos);
 		pos = strtok(NULL, "=");
 		if (!pos) {
 			free(line);
 			fclose(fd);
 			return SELINT_PARSE_ERROR;
 		}
-		char *status = strip_space(pos);
+		const char *status = strip_space(pos);
 		insert_into_mods_map(mod_name, status);
 		if (strtok(NULL, "=")) {
 			free(line);
@@ -172,7 +242,7 @@ enum selint_error load_modules_source(const char *modules_conf_path)
 
 enum selint_error load_obj_perm_sets_source(const char *obj_perm_sets_path)
 {
-	FILE *f = fopen(obj_perm_sets_path, "r");
+	FILE *f = fopen(obj_perm_sets_path, "re");
 	if (!f) {
 		return SELINT_IO_ERROR;
 	}
@@ -221,14 +291,12 @@ static int mark_transform_interfaces_one_file(const struct policy_node *ast) {
 
 enum selint_error load_devel_headers(struct policy_file_list *context_files)
 {
-	const char *header_loc = "/usr/share/selinux/devel";
-	const char *paths[2] = {header_loc, 0};
+	char header_loc[] = "/usr/share/selinux/devel";
+	char *const paths[2] = { header_loc, NULL };
 
-IGNORE_CONST_DISCARD_BEGIN;
 	FTS *ftsp = fts_open(paths, FTS_PHYSICAL | FTS_NOSTAT, NULL);
-IGNORE_CONST_DISCARD_END;
 
-	FTSENT *file = fts_read(ftsp);
+	const FTSENT *file = fts_read(ftsp);
 	while (file) {
 		const char *suffix = (file->fts_pathlen > 3) ? (file->fts_path + file->fts_pathlen - 3) : NULL;
 		if (suffix && !strcmp(suffix, ".if")) {
@@ -253,7 +321,7 @@ static enum selint_error load_global_conditions_file(const char *path)
 
 	set_current_module_name("__global__");
 
-	FILE *f = fopen(path, "r");
+	FILE *f = fopen(path, "re");
 	if (!f) {
 		printf("%sError%s: Failed to open file %s: %s\n", color_error(), color_reset(), path, strerror(errno));
 		return SELINT_IO_ERROR;
