@@ -531,9 +531,9 @@ struct check_result *check_no_explicit_declaration(const struct check_data *data
 			flavor = DECL_ATTRIBUTE;
 		} else if (name_is_roleattr(ndata) && (mod_name = look_up_in_decl_map(ndata->name, DECL_ATTRIBUTE_ROLE))) {
 			flavor = DECL_ATTRIBUTE_ROLE;
-		} else if (name_is_class(ndata) && look_up_in_decl_map(name->data->name, DECL_CLASS)) {
+		} else if (name_is_class(ndata) && look_up_in_decl_map(ndata->name, DECL_CLASS)) {
 			// Ignore kernel classes
-			if (!userspace_class_support || !is_userspace_class(name->data->name, name->data->traits)) {
+			if (!userspace_class_support || !is_userspace_class(ndata->name, ndata->traits)) {
 				continue;
 			}
 			flavor = DECL_CLASS;
@@ -1032,10 +1032,10 @@ struct check_result *check_stray_word(const struct check_data
 
 	// ignore comparison arguments to ifelse
 	// (do not ignore last node of block, which is never a comparison argument)
-	const struct policy_node *ifelse_arument = is_ifelse_argument(node);
-	if (ifelse_arument && ifelse_arument->next) {
+	const struct policy_node *ifelse_argument = is_ifelse_argument(node);
+	if (ifelse_argument && ifelse_argument->next) {
 		int position = 0;
-		for (const struct policy_node *cur = ifelse_arument; cur->prev; cur = cur->prev) {
+		for (const struct policy_node *cur = ifelse_argument; cur->prev; cur = cur->prev) {
 			position++;
 		}
 
