@@ -25,10 +25,12 @@
 #define BASIC_TE_FILENAME POLICIES_DIR "basic.te"
 #define BASIC_IF_FILENAME POLICIES_DIR "basic.if"
 #define UNCOMMON_TE_FILENAME POLICIES_DIR "uncommon.te"
+#define IFDEF_IF_FILENAME POLICIES_DIR "ifdef.if"
 #define BLOCKS_TE_FILENAME POLICIES_DIR "blocks.te"
 #define EMPTY_TE_FILENAME POLICIES_DIR "empty.te"
 #define SYNTAX_ERROR_FILENAME POLICIES_DIR "syntax_error.te"
 #define BAD_RA_FILENAME POLICIES_DIR "bad_role_allow.te"
+#define DISABLE_BOOLTUNABLE_TE_FILENAME POLICIES_DIR "disable_booltunable.te"
 #define DISABLE_COMMENT_TE_FILENAME POLICIES_DIR "disable_comment.te"
 #define DISABLE_COMMENT_IF_FILENAME POLICIES_DIR "disable_comment.if"
 #define DISABLE_REQUIRE_IF_FILENAME POLICIES_DIR "disable_require.if"
@@ -275,6 +277,23 @@ START_TEST (test_parse_uncommon_constructs) {
 }
 END_TEST
 
+START_TEST (test_parse_interface_ifdef) {
+
+	set_current_module_name("ifdef");
+
+	FILE *f = fopen(IFDEF_IF_FILENAME, "r");
+	ck_assert_ptr_nonnull(f);
+	struct policy_node *ast = yyparse_wrapper(f, IFDEF_IF_FILENAME, NODE_IF_FILE);
+	ck_assert_ptr_nonnull(ast);
+
+	ck_assert_ptr_nonnull(ast);
+
+	free_policy_node(ast);
+	cleanup_parsing();
+	fclose(f);
+}
+END_TEST
+
 START_TEST (test_parse_blocks) {
 
 	set_current_module_name("blocks");
@@ -360,6 +379,51 @@ START_TEST (test_parse_bad_role_allow) {
 }
 END_TEST
 
+START_TEST (test_disable_booltunable_te) {
+
+	set_current_module_name("disable_booltunable");
+
+	FILE *f = fopen(DISABLE_BOOLTUNABLE_TE_FILENAME, "r");
+	ck_assert_ptr_nonnull(f);
+	struct policy_node *ast = yyparse_wrapper(f, DISABLE_BOOLTUNABLE_TE_FILENAME, NODE_TE_FILE);
+	ck_assert_ptr_nonnull(ast);
+
+	const struct policy_node *cur = ast;
+
+	ck_assert_ptr_nonnull(cur);
+	ck_assert_int_eq(NODE_TE_FILE, cur->flavor);
+	ck_assert_ptr_nonnull(cur->next);
+
+	cur = cur->next;
+	ck_assert_int_eq(NODE_HEADER, cur->flavor);
+	ck_assert_ptr_nonnull(cur->next);
+
+	cur = cur->next;
+	ck_assert_int_eq(NODE_DECL, cur->flavor);
+	ck_assert_ptr_nonnull(cur->next);
+
+	cur = cur->next;
+	ck_assert_int_eq(NODE_TUNABLE_POLICY, cur->flavor);
+	ck_assert_str_eq("C-008", cur->exceptions);
+	ck_assert_ptr_nonnull(cur->next);
+
+	cur = cur->next;
+	ck_assert_int_eq(NODE_TUNABLE_POLICY, cur->flavor);
+	ck_assert_str_eq("C-008", cur->exceptions);
+	ck_assert_ptr_nonnull(cur->next);
+
+	cur = cur->next;
+	ck_assert_int_eq(NODE_BOOLEAN_POLICY, cur->flavor);
+	ck_assert_str_eq("C-008", cur->exceptions);
+	ck_assert_ptr_null(cur->next);
+
+	free_policy_node(ast);
+	cleanup_parsing();
+	fclose(f);
+
+}
+END_TEST
+
 START_TEST (test_disable_comment_te) {
 
 	set_current_module_name("disable_comment");
@@ -1062,10 +1126,12 @@ static Suite *parsing_suite(void) {
 	tcase_add_test(tc_core, test_parse_basic_te);
 	tcase_add_test(tc_core, test_parse_basic_if);
 	tcase_add_test(tc_core, test_parse_uncommon_constructs);
+	tcase_add_test(tc_core, test_parse_interface_ifdef);
 	tcase_add_test(tc_core, test_parse_blocks);
 	tcase_add_test(tc_core, test_parse_empty_file);
 	tcase_add_test(tc_core, test_syntax_error);
 	tcase_add_test(tc_core, test_parse_bad_role_allow);
+	tcase_add_test(tc_core, test_disable_booltunable_te);
 	tcase_add_test(tc_core, test_disable_comment_te);
 	tcase_add_test(tc_core, test_disable_comment_if);
 	tcase_add_test(tc_core, test_disable_require_if);
